#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Primitivus: a SAT frontend
Copyright (C) 2009, 2010  Jérôme Poisson (goffi@goffi.org)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import urwid
from quick_frontend.quick_contact_list import QuickContactList
from custom_widgets import Password,List,InputDialog,ConfirmDialog,Alert


class ContactList(urwid.WidgetWrap, QuickContactList):

    def __init__(self, host, CM):
        QuickContactList.__init__(self, CM)
        self.host = host
               
        self.list_wid = List([], style=['single'], align='left')

        #we now build the widget
        body_content = urwid.SimpleListWalker([self.list_wid])
        frame_body = urwid.ListBox(body_content)
        frame = urwid.Frame(frame_body,urwid.AttrMap(urwid.Text(_("Contacts"),align='center'),'title'))
        self.main_widget = urwid.LineBox(frame)
        urwid.WidgetWrap.__init__(self, self.main_widget)
            
    def clear_contacts(self):
        """clear all the contact list"""
        self.list_wid.changeValues([])

    def replace(self, jid, groups=None):
            """add a contact to the list if doesn't exist, else update it"""
            contacts = self.list_wid.getValues()
            if jid.short not in contacts:
                contacts.append(jid.short)
                contacts.sort()
                self.list_wid.changeValues(contacts)
    
    def disconnect(self, jid):
        """mark a contact disconnected"""
        self.remove(jid)
    
    def remove(self, jid):
        """remove a contact from the list"""
        self.list_wid.deleteValue(jid.short)
    
    def add(self, jid, param_groups=None):
        """add a contact to the list"""
        self.replace(jid)

